.. _child_example_two-name:

!!!!!!!!!!!!!!!!!
child_example_two
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: child_example_two, second, child, page

.. index:: child_example_two, second, child, page

.. _child_example_two-title:

Second Child Example Page
#########################

.. contents::
   :local:

.. meta::
   :keywords: links

.. index:: links

.. _child_example_two@Links:

Links
*****
- :ref:`parent<toc_list_example-title>`
- :ref:`first child<child_example_one-title>`

.. _child_example_two@This Example File:

This Example File
*****************
:ref:`child_example_one@This Example File`
is the same as for the first child page.
